==> Decorative%20Food-1.20.1-1.0.3-sources.jar: org/dfood/mixin/client/RenderLayerMixin.java <==
package org.dfood.mixin.client;

import org.dfood.block.FoodBlocks;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Map;
import net.minecraft.class_1921;
import net.minecraft.class_2248;
import net.minecraft.class_4696;

@Mixin(class_4696.class)
public class RenderLayerMixin {
    @Shadow @Final private static Map<class_2248, class_1921> BLOCKS;

    @Inject(method = "<clinit>", at = @At("RETURN"))
    private static void init(CallbackInfo ci) {
        BLOCKS.put(FoodBlocks.APPLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GOLDEN_APPLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GOLDEN_CARROT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.BEETROOT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COD, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COOKED_COD, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SALMON, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COOKED_SALMON, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.CHORUS_FRUIT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SWEET_BERRIES, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GLOW_BERRIES, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.CARROT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.POTION, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SUSPICIOUS_STEW, class_1921.method_23581());
    }
}

==> Decorative%20Food-1.20.1-1.0.7-sources.jar: org/dfood/mixin/client/RenderLayerMixin.java <==
package org.dfood.mixin.client;

import org.dfood.block.FoodBlocks;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Map;
import net.minecraft.class_1921;
import net.minecraft.class_2248;
import net.minecraft.class_4696;

@Mixin(class_4696.class)
public class RenderLayerMixin {
    @Shadow @Final private static Map<class_2248, class_1921> BLOCKS;

    @Inject(method = "<clinit>", at = @At("RETURN"))
    private static void init(CallbackInfo ci) {
        BLOCKS.put(FoodBlocks.APPLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GOLDEN_APPLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GOLDEN_CARROT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.BEETROOT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COD, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COOKED_COD, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SALMON, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.COOKED_SALMON, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.CHORUS_FRUIT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SWEET_BERRIES, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GLOW_BERRIES, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.CARROT, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.POTION, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.GLASS_BOTTLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.HONEY_BOTTLE, class_1921.method_23581());
        BLOCKS.put(FoodBlocks.SUSPICIOUS_STEW, class_1921.method_23581());
    }
}
